==> gcstar_1.4.3.orig.tar.gz: gcstar/lib/gcstar/GCLang/NL/GCModels/GCcomics.pm <==
{
    package GCLang::NL::GCModels::GCcomics;

    use utf8;
###################################################
#
#  Auteursrecht 2005-2007 Tian
#
#  Dit bestand is onderdeel van GCstar.
#
#  GCstar is gratis software; je kan het verspreiden en/ of wijzigen
#  onder de voorwaarden van de GNU General Public License zoals gepubliceerd door
#  de Free Software Foundation; ofwel versie 2 van de licentie, of
#  (op uw keuze) een latere versie.
#
#  GCstar wordt verspreid in de hoop dat het nuttig zal zijn
#  maar ZONDER ENIGE GARANTIE, zelfs zonder de impliciete garantie van
#  Verkoopbaarheid of geschiktheid voor een bepaald doel. Zie de
#  GNU General Public License voor meer details.
#
#  Je zou een kopie van de GNU General Public License moeten ontvangen hebben
#  samen met GCstar; zo niet, schrijf naar de Free Software
#  Foundation, Inc, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Strips collectie',
        Items => {0 => 'Strips',
                  1 => 'Strip',
                  X => 'Strips'},
        NewItem => 'Nieuwe strip',
    
    
        Id => 'Id',
        Name => 'Naam',
        Series => 'Series',
        Volume => 'Deel',
        Title => 'Titel',
        Writer => 'Schrijver',
        Illustrator => 'Illustrator',
        Colourist => 'Colorist',
        Publisher => 'Uitgever',
        Synopsis => 'Synopsis',
        Collection => 'Collectie',
        PublishDate => 'Publicatie datum',
        PrintingDate => 'Afdruk Datum',
        ISBN => 'ISBN',
        Type => 'Type',
		Category => 'Categorie',
        Format => 'Formaat',
        NumberBoards => 'Aantal',
		Signing => 'Ondertekening',
        Cost => 'Kost',
        Rating => 'Waardering',
        Comment => 'Opmerkingen',
        Url => 'Webpagina',

        FilterRatingSelect => 'Minimum waardering...',

        Main => 'Belangrijkste punten',
        General => 'Algemeen',
        Details => 'Details',
     );
}

1;

==> gcstar_1.7.0.orig.tar.gz: gcstar/lib/gcstar/GCLang/NL/GCModels/GCcomics.pm <==
{
    package GCLang::NL::GCModels::GCcomics;

    use utf8;
###################################################
#
#  Auteursrecht 2005-2009 Tian
#
#  Dit bestand is onderdeel van GCstar.
#
#  GCstar is gratis software; je kan het verspreiden en/ of wijzigen
#  onder de voorwaarden van de GNU General Public License zoals gepubliceerd door
#  de Free Software Foundation; ofwel versie 2 van de licentie, of
#  (op uw keuze) een latere versie.
#
#  GCstar wordt verspreid in de hoop dat het nuttig zal zijn
#  maar ZONDER ENIGE GARANTIE, zelfs zonder de impliciete garantie van
#  Verkoopbaarheid of geschiktheid voor een bepaald doel. Zie de
#  GNU General Public License voor meer details.
#
#  Je zou een kopie van de GNU General Public License moeten ontvangen hebben
#  samen met GCstar; zo niet, schrijf naar de Free Software
#  Foundation, Inc, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Collectie strips',
        Items => {0 => 'Strips',
                  1 => 'Strip',
                  X => 'Strips'},
        NewItem => 'Nieuwe strip',
    
    
        Id => 'Id',
        Name => 'Naam',
        Series => 'Series',
        Volume => 'Deel',
        Title => 'Titel',
        Writer => 'Schrijver',
        Illustrator => 'Illustrator',
        Colourist => 'Colorist',
        Publisher => 'Uitgever',
        Synopsis => 'Synopsis',
        Collection => 'Collectie',
        PublishDate => 'Publicatiedatum',
        PrintingDate => 'Afdrukdatum',
        ISBN => 'ISBN',
        Type => 'Type',
		Category => 'Categorie',
        Format => 'Formaat',
        NumberBoards => 'Aantal',
		Signing => 'Ondertekening',
        Cost => 'Kost',
        Rating => 'Waardering',
        Comment => 'Opmerkingen',
        Url => 'Webpagina',

        FilterRatingSelect => 'Minimum waardering...',

        Main => 'Belangrijkste punten',
        General => 'Algemeen',
        Details => 'Details',
     );
}

1;
